button{cursor:pointer;border:0;border-radius:4px;font-weight:600;margin:0;width:200px;padding:10px 0;transition:.4s}.log{color:var(--text-color);background-color:var(--background-color);border:1px solid var(--primary-color)}button:hover{color:#fff;background-color:var(--primary-color)}
